@@ -4,7 +4,7 @@
 flush <- appendVarArgs(flush);
 write <- appendVarArgs(write);
 if (exists("restart", mode="function")) {
-  restart <- NULL; rm("restart"); # To please R CMD check on R (>= 2.15.0)
+  restart <- NULL; rm(list="restart"); # To please R CMD check on R (>= 2.15.0)
   restart <- appendVarArgs(restart);
 }
 
